@@ -29,7 +29,8 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><img .*? src="_images/.*?.png" .*?/></div>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<img .*? src="_images/.*?.png" .*?/></div>'))
 
     @with_app(srcdir='tests/docs/subdir', buildername='html', write_docstring=True)
     def test_build_png_image_in_subdir(self, app, status, warning):
@@ -40,7 +41,8 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'subdir' / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><img .*? src="\.\./_images/.*?.png" .*?/></div>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<img .*? src="\.\./_images/.*?.png" .*?/></div>'))
 
     @with_png_app
     def test_width_option_on_png(self, app, status, warning):
@@ -52,8 +54,9 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="97.0" src="\\1" width="224.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="97.0" src="\1" width="224.0" /></a></div>'))
 
     @with_png_app
     def test_height_option_on_png(self, app, status, warning):
@@ -65,8 +68,9 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="97.0" src="\\1" width="224.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="97.0" src="\1" width="224.0" /></a></div>'))
 
     @with_png_app
     def test_width_option_and_height_option_on_png(self, app, status, warning):
@@ -79,8 +83,9 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="200.0" src="\\1" width="100.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="200.0" src="\1" width="100.0" /></a></div>'))
 
     @with_png_app
     def test_scale_option_on_png(self, app, status, warning):
@@ -92,8 +97,9 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="48.5" src="\\1" width="112.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="48.5" src="\1" width="112.0" /></a></div>'))
 
     @with_png_app
     def test_width_option_and_scale_option_on_png(self, app, status, warning):
@@ -106,8 +112,9 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="3.03125" src="\\1" width="7.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="3.03125" src="\1" width="7.0" /></a></div>'))
 
     @with_png_app
     def test_align_option_on_png(self, app, status, warning):
@@ -119,7 +126,7 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div align="center" class="align-center"><img .*? /></div>')
+        self.assertRegexpMatches(source, r'<div class="align-center"><img .*? /></div>')
 
     @with_png_app
     def test_align_option_and_width_option_on_png(self, app, status, warning):
@@ -132,9 +139,9 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div align="center" class="align-center">'
-                                          '<a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="97.0" src="\\1" width="224.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-center">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="97.0" src="\1" width="224.0" /></a></div>'))
 
     @with_png_app
     def test_name_option_on_png(self, app, status, warning):
@@ -146,7 +153,8 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><img .*? id="target" src=".*?" .*? /></div>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<img .*? id="target" src=".*?" .*? /></div>'))
 
     @with_png_app
     def test_name_option_and_width_option_on_png(self, app, status, warning):
@@ -159,8 +167,9 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="97.0" id="target" src="\\1" width="224.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="97.0" id="target" src="\1" width="224.0" /></a></div>'))
 
     @with_png_app
     def test_href_and_scale_option_on_png(self, app, status, warning):
@@ -173,11 +182,12 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<map name="(map_\d+)">'
-                                          '<area shape="rect" coords="32.0,20.0,96.0,40.0" '
-                                          'href="http://blockdiag.com/"></map>'
-                                          '<img .*? src="\\1" usemap="#\\2" .*?/></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<map name="(map_\d+)">'
+                                          r'<area shape="rect" coords="32.0,20.0,96.0,40.0" '
+                                          r'href="http://blockdiag.com/"></map>'
+                                          r'<img .*? src="\1" usemap="#\2" .*?/></a></div>'))
 
     @with_png_app
     def test_reftarget_in_href_on_png1(self, app, status, warning):
@@ -194,9 +204,9 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><map name="(map_\d+)">'
-                                          '<area shape="rect" coords="64.0,40.0,192.0,80.0" href="#target"></map>'
-                                          '<img .*? src=".*?.png" usemap="#\\1" .*?/></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default"><map name="(map_\d+)">'
+                                          r'<area shape="rect" coords="64.0,40.0,192.0,80.0" href="#target"></map>'
+                                          r'<img .*? src=".*?.png" usemap="#\1" .*?/></div>'))
 
     @with_png_app
     def test_reftarget_in_href_on_png2(self, app, status, warning):
@@ -213,9 +223,9 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><map name="(map_\d+)">'
-                                          '<area shape="rect" coords="64.0,40.0,192.0,80.0" href="#hello-world">'
-                                          '</map><img .*? src=".*?.png" usemap="#\\1" .*?/></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default"><map name="(map_\d+)">'
+                                          r'<area shape="rect" coords="64.0,40.0,192.0,80.0" href="#hello-world">'
+                                          r'</map><img .*? src=".*?.png" usemap="#\1" .*?/></div>'))
 
     @with_png_app
     def test_missing_reftarget_in_href_on_png(self, app, status, warning):
@@ -227,7 +237,8 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><img .*? src=".*?.png" .*?/></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<img .*? src=".*?.png" .*?/></div>'))
         self.assertIn('undefined label: unknown_target', warning.getvalue())
 
     @with_svg_app
@@ -239,7 +250,7 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><svg .*?>')
+        self.assertRegexpMatches(source, r'<div class="align-default"><svg .*?>')
 
     @with_svg_app
     def test_width_option_on_svg(self, app, status, warning):
@@ -251,7 +262,8 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><svg height="97.0" viewBox="0 0 448 194" width="224.0" .*?>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<svg height="97.0" viewBox="0 0 448 194" width="224.0" .*?>'))
 
     @with_svg_app
     def test_height_option_on_svg(self, app, status, warning):
@@ -263,7 +275,8 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><svg height="97.0" viewBox="0 0 448 194" width="224.0" .*?>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<svg height="97.0" viewBox="0 0 448 194" width="224.0" .*?>'))
 
     @with_svg_app
     def test_width_option_and_height_option_on_svg(self, app, status, warning):
@@ -276,7 +289,8 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><svg height="200.0" viewBox="0 0 448 194" width="100.0" .*?>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<svg height="200.0" viewBox="0 0 448 194" width="100.0" .*?>'))
 
     @with_svg_app
     def test_scale_option_on_svg(self, app, status, warning):
@@ -288,7 +302,8 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><svg height="48.5" viewBox="0 0 448 194" width="112.0" .*?>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<svg height="48.5" viewBox="0 0 448 194" width="112.0" .*?>'))
 
     @with_svg_app
     def test_width_option_and_scale_option_on_svg(self, app, status, warning):
@@ -301,7 +316,8 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><svg height="3.03125" viewBox="0 0 448 194" width="7.0" .*?>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<svg height="3.03125" viewBox="0 0 448 194" width="7.0" .*?>'))
 
     @with_svg_app
     def test_align_option_on_svg(self, app, status, warning):
@@ -313,7 +329,7 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div align="center" class="align-center"><svg .*?>')
+        self.assertRegexpMatches(source, r'<div class="align-center"><svg .*?>')
 
     @with_svg_app
     def test_name_option_on_svg(self, app, status, warning):
@@ -325,7 +341,8 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><span id="target"></span><svg .*?>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<span id="target"></span><svg .*?>'))
 
     @with_svg_app
     def test_reftarget_in_href_on_svg1(self, app, status, warning):
@@ -342,7 +359,7 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<a xlink:href="#target">\\n\\s*<rect .*?>\\n\\s*</a>')
+        self.assertRegexpMatches(source, r'<a xlink:href="#target">\n\s*<rect .*?>\n\s*</a>')
 
     @with_svg_app
     def test_reftarget_in_href_on_svg2(self, app, status, warning):
@@ -359,7 +376,7 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<a xlink:href="#hello-world">\\n\\s*<rect .*?>\\n\\s*</a>')
+        self.assertRegexpMatches(source, r'<a xlink:href="#hello-world">\n\s*<rect .*?>\n\s*</a>')
 
     @with_svg_app
     def test_missing_reftarget_in_href_on_svg(self, app, status, warning):
@@ -372,9 +389,9 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
         if sys.version_info < (3, 0):
-            self.assertNotRegexpMatches(source, '<a xlink:href="#hello-world">\\n\\s*<rect .*?>\\n\\s*</a>')
+            self.assertNotRegexpMatches(source, r'<a xlink:href="#hello-world">\n\s*<rect .*?>\n\s*</a>')
         else:
-            self.assertNotRegex(source, '<a xlink:href="#hello-world">\\n\\s*<rect .*?>\\n\\s*</a>')
+            self.assertNotRegex(source, r'<a xlink:href="#hello-world">\n\s*<rect .*?>\n\s*</a>')
         self.assertIn('undefined label: unknown_target', warning.getvalue())
 
     @with_svg_app
@@ -395,4 +412,4 @@ class TestSphinxcontribSeqdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<text[^>]+>A_foo</text>')  # 2nd diagram has a node labeled 'A_foo'.
+        self.assertRegexpMatches(source, r'<text[^>]+>A_foo</text>')  # 2nd diagram has a node labeled 'A_foo'.
